@@ -2,8 +2,8 @@ package MouseX::Getopt::GLD;
 BEGIN {
   $MouseX::Getopt::GLD::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MouseX::Getopt::GLD::VERSION = '0.32';
+BEGIN {
+  $MouseX::Getopt::GLD::VERSION = '0.33';
 }
 # ABSTRACT: A Mouse role for processing command line options with Getopt::Long::Descriptive
 
@@ -122,6 +122,10 @@ FUJI Goro <gfuji@cpan.org>
 
 =item *
 
+Tokuhiro Matsuno <tokuhirom@cpan.org>
+
+=item *
+
 Stevan Little <stevan@iinteractive.com>
 
 =item *
@@ -160,15 +164,11 @@ Avar Arnfjord Bjarmason <avar@cpan.org>
 
 Chris Prather <perigrin@cpan.org>
 
-=item *
-
-Mark Gardner <mjgardner@cpan.org>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc.
+This software is copyright (c) 2010 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
